@@ -550,24 +550,37 @@ void MainWindow::runscript(QString command)
         progress.setValue(90);
   //      sleep(1);
   //      QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."), QMaemo5InformationBox::DefaultTimeout);
+        system("/usr/sbin/dsmetool -k /usr/bin/hildon-home");
+        // sleep(1);
+        progress.setValue(92);
+        system("killall hildon-status-menu");
+        // sleep(1);
         system("ps ax | grep -v grep | grep osso-abook-home-applet > /dev/null && killall osso-abook-home-applet && sleep 2 &&  ps ax | grep -v grep | grep osso-abook-home-applet || /usr/sbin/dsmetool -t /usr/bin/osso-abook-home-applet");
-        sleep(1);
+        progress.setValue(93);
+        // sleep(1);
         system("killall systemui");
-        sleep(1);
+        progress.setValue(94);
+        // sleep(1);
         system("killall browser browserd");
-        sleep(1);
-        system("killall rtcom-messaging-ui");
         progress.setValue(95);
-        sleep(1);
+        // sleep(1);
+        system("killall rtcom-messaging-ui");
+        progress.setValue(96);
+        // sleep(1);
         system("killall rtcom-call-ui");
-        sleep(1);
-        systemcommand.clear();
-        systemcommand << "restartservices";
-	QProcess *muoks8 = new QProcess(this);
-	muoks8->start("/sbin/launchcustomizer", systemcommand);
-	muoks8->waitForFinished();
-        progress.cancel();
+        progress.setValue(97);
+        // sleep(1);
+        system("/usr/sbin/dsmetool -t /usr/bin/hildon-home; sleep 2");
+        progress.setValue(98);
+   //     sleep(4);
+        // systemcommand.clear();
+        // systemcommand << "restartservices";
+	// QProcess *muoks8 = new QProcess(this);
+	// muoks8->start("/sbin/launchcustomizer", systemcommand);
+	// muoks8->waitForFinished();
+        progress.setValue(99);
         QMaemo5InformationBox::information(this, tr("Theme customizations applied!") +  "<br /><br />" + tr("Restart the device to reload all theme elements and make all changes visible."), QMaemo5InformationBox::NoTimeout);
+        progress.cancel();
 //	sleep(2);
 //        system("killall theme-customizer");
 
@@ -824,7 +837,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-61<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-62<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -1196,10 +1209,27 @@ void MainWindow::on_label_clicked()
 //    connect(process2, SIGNAL(finished(int)), this, SLOT(process2Finished(int)));
     process2->start("/usr/bin/personalisation_app");
     process2->waitForFinished();
-    sleep(2);
+    QString varattu3;
+    varattu3 = tr("Reading settings");
+    progress3.setWindowModality(Qt::WindowModal);
+    progress3.setWindowTitle(varattu3);
+    progress3.setCancelButton(0);
+    progress3.setValue(0);
+    progress3.show();
+    progress3.setValue(5);
     readdirs();
     oldfonts("/etc/hildon/theme/colors.config");
+    progress3.setValue(20);
     readgtkrc();
+    progress3.setValue(30);
+    progress3.setValue(35);
+    progress3.setValue(45);
+    progress3.setValue(50);
+    progress3.setValue(60);
+    progress3.setValue(70);
+    progress3.setValue(80);
     readSettings();
     writeSettings();
+    progress3.setValue(100);
+    progress3.cancel();    
 }
