@@ -8,6 +8,14 @@
         <source>Theme Customizer</source>
         <translation>Customiser le thème</translation>
     </message>
+    <message>
+        <source>Theme customizations applied!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Restart the device to reload all theme elements and make all changes visible.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Current theme: </source>
         <translation>Thème actuel: </translation>
